module UU
  module OS
    module CMD

      # Default session handler. As custom handler might be used any class (or object instance)
      # which responds to {#handle_session handle_session} method.
      class SessionHandler

        # Propagates data from given session object to corresponding HTTP headers and query parameters.
        # @param [#access_token Hash] session Session can be represented by any object responding to
        #    following methods (or Hash containing following keys):
        #
        #    * #access_token (:accessToken) - Returns value to be used in Authorization header.
        # @param [UU::OS::HTTP::HTTPHeaders] http_headers Modifiable original request headers.
        # @param [UU::OS::HTTP::HTTPQuery] http_parameters Modifiable original request query parameters.
        # @return [void]
        def handle_session(session, http_headers, http_parameters)
          return if session.nil?
          access_token = nil
          if session.kind_of?Hash
            access_token = session[:accessToken]
          else
            access_token = session.access_token if session.respond_to?(:access_token)
          end
          http_headers[:authorization] = access_token if access_token
        end

      end

    end
  end
end
